% OKAN University
% MF and FBE Graduation Project, Thesis and Dissertation Class
% Copyright (C) 2012 by Burak Kelleci
%
% Change History:
%   1)  Initial version

% ---------- identification ----------
\NeedsTeXFormat{LaTeX2e}[1995/12/01]
\ProvidesClass{mfthesis}[2017/09/21 Okan University Engineering Faculty Thesis Class v0.2]
% ---------- initial code ----------
\newcommand{\pt@size}{}	% \@ptsize declared in report.cls so using \pt@size
\newif\ifEnglish
\newif\ifBSC
\newif\ifMSC
\newif\ifPHD
\newif\ifArial
\newif\ifIndent
\newif\ifRefIEEE
% ---------- declaration of options ----------
\DeclareOption{draft}{\setlength{\overfullrule}{5pt}%
 \PassOptionsToClass{\CurrentOption}{report}}
\DeclareOption{final}{\setlength{\overfullrule}{0pt}%
 \PassOptionsToClass{\CurrentOption}{report}}
\DeclareOption{twoside}{\@twosidetrue	\@mparswitchtrue%
 \PassOptionsToClass{\CurrentOption}{report}}
%  Only a4 size paper acceptable
\DeclareOption{legalpaper}{%
 \ClassWarningNoLine{eethesis}{'legalpaper' option not acceptable (defaulting to 'a4paper')}}
\DeclareOption{executivepaper}{%
 \ClassWarningNoLine{eethesis}{'executivepaper' option not acceptable (defaulting to 'a4paper')}}
\DeclareOption{letterpaper}{%
 \ClassWarningNoLine{eethesis}{'letterpaper' option not acceptable (defaulting to 'a4paper')}}
\DeclareOption{a5paper}{%
 \ClassWarningNoLine{eethesis}{'a5paper' option not acceptable (defaulting to 'a4paper')}}
\DeclareOption{b5paper}{%
 \ClassWarningNoLine{eethesis}{'b5paper' option not acceptable (defaulting to 'a4paper')}}
\PassOptionsToClass{a4paper}{report}
% Only Single column is allowed
\DeclareOption{twocolumn}{%
 \ClassWarningNoLine{eethesis}{'twocolumn' option not acceptable (defaulting to 'onecolumn')}}
\PassOptionsToClass{onecolumn}{report}

\ifArial	%Arial is 11pt
 \renewcommand{\pt@size}{11}
 \PassOptionsToClass{11pt}{report}
\else % Times New Romam is 12pt
 \renewcommand{\pt@size}{12}
 \PassOptionsToClass{12pt}{report}
\fi

\DeclareOption{English}{\Englishtrue}
\DeclareOption{Turkce}{\Englishfalse}
\DeclareOption{BSC}{\BSCtrue \MSCfalse \PHDfalse}
\DeclareOption{MSC}{\BSCfalse \MSCtrue \PHDfalse}
\DeclareOption{PHD}{\BSCfalse \MSCfalse \PHDtrue}
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{report}}
\DeclareOption{Arial}{\Arialtrue}
\DeclareOption{Times}{\Arialfalse}
\DeclareOption{Indent}{\Indenttrue}
\DeclareOption{NoIndent}{\Indentfalse}
\DeclareOption{IEEE}{\RefIEEEtrue}
\DeclareOption{Natbib}{\RefIEEEfalse}
% ---------- execution of options ----------
\ExecuteOptions{a4paper,final,onecolumn,English,BSC,Times,Indent,IEEE}
\ProcessOptions
% ---------- package loading ----------
\LoadClass{report}

\ClassInfo{mfthesis}{Okan University Latex Class v0.1\MessageBreak Prepared by Burak Kelleci}

\ifEnglish
\ClassInfo{mfthesis}{English Mod\MessageBreak}
\else
\ClassInfo{mfthesis}{Turkce Mod\MessageBreak}
\fi

%Add various packages

\usepackage{ifpdf}
\ifpdf
\usepackage[pdftex]{graphicx}        % standard LaTeX graphics tool
%\usepackage[debug,pdftex,linktocpage,unicode,colorlinks]{hyperref}
\else
\usepackage{graphicx}        % standard LaTeX graphics tool
%\usepackage[debug,linktocpage,unicode,colorlinks]{hyperref}
\fi
\usepackage{textcase}        % Add Text Case Package to Handle Uppercase
\usepackage{multirow}
\usepackage{array}
\usepackage{subfigure}
\usepackage{pdflscape}
%\usepackage{amssymb,amsmath}
\usepackage{amsmath}
\usepackage{listings}
\usepackage{enumerate}
\usepackage[parfill]{parskip}
%\usepackage{harvard} % Harvard biblio package
%\usepackage[none]{hyphenat} % No Hypehenation
\usepackage{tablefootnote}
\usepackage[strict]{changepage}
%\usepackage[latin5]{inputenc} % Required for turkish characters
\usepackage[T1]{fontenc}	% Required for turkish hypenation

\ifRefIEEE
\else
\usepackage[comma]{natbib}
\fi

%  ****************************************
%  *               FONTS                  *
%  ****************************************

% Change default font to Times Family
%\renewcommand{\rmdefault}{ptm}

% If Arial is selected change font family to Arial
\ifArial
\renewcommand{\rmdefault}{phv} % Arial
\renewcommand{\sfdefault}{phv} % Arial
\fi


\newcommand{\tocspace}{\baselineskip=16pt}
\newcommand{\singlespace}{\baselineskip=12pt}
\newcommand{\oneandhalfspace}{\baselineskip=16pt}
\newcommand{\refspace}{\baselineskip=15pt}
\newcommand{\doublespace}{\baselineskip=24pt}
%\newcommand{\tocspace}{\onehalfspacing}
%\newcommand{\singlespace}{\singlespacing}
%\newcommand{\oneandhalfspace}{\onehalfspacing}
%\newcommand{\refspace}{\onehalfspacing}
%\def{\doublespace}{\doublespacing}
\def\body{
   \pagenumbering{arabic}\setcounter{page}{1}
   \doublespace
   \setlength{\headheight}{12pt}
   \pagestyle{myheadings}
   \def\@thefnmark{\char32}
   }
%
\lineskip 1pt            % \lineskip is 1pt for all font sizes.
\normallineskip 1pt
\renewcommand{\baselinestretch}{1}

% Each size-changing command \SIZE executes the command
%        \@setsize\SIZE{BASELINESKIP}\FONTSIZE\@FONTSIZE
% where:
%   BASELINESKIP = Normal value of \baselineskip for that size.  (Actual
%                  value will be \baselinestretch * BASELINESKIP.)
%
%  \FONTSIZE     = Name of font-size command.  The currently available
%                  (preloaded) font sizes are: \vpt (5pt), \vipt (6pt),
%                  \viipt (etc.), \viiipt, \ixpt, \xpt, \xipt, \xiipt,
%                  \xivpt, \xviipt, \xxpt, \xxvpt.
%  \@FONTSIZE    = The same as the font-size command except with an
%                  '@' in front---e.g., if \FONTSIZE = \xivpt then
%                  \@FONTSIZE = \@xivpt.
%
% For reasons of efficiency that needn't concern the designer,
% the document style defines \@normalsize instead of \normalsize .  This is
% done only for \normalsize, not for any other size-changing commands.

%\@vpt 5 \@vipt 6 \@viipt 7
%\@viiipt 8 \@ixpt 9 \@xpt 10
%\@xipt 10.95 \@xiipt 12 \@xivpt 14.4

% {@xipt}{13.6} : {Font Size}{Distance between} 

\ifArial %Arial is 11pt

\renewcommand{\normalsize}{
\@setfontsize\normalsize\@xipt{13.6}%
\abovedisplayskip 11pt plus 3pt minus 6pt%
\belowdisplayskip \abovedisplayskip
\abovedisplayshortskip  \z@ plus 3pt%
\belowdisplayshortskip  6.5pt plus 3.5pt minus 3pt}

\renewcommand{\small}{
\@setfontsize\small\@xpt\@xiipt%
\abovedisplayskip 10pt plus 2pt minus 5pt%
\belowdisplayskip \abovedisplayskip
\abovedisplayshortskip  \z@ plus 3pt%
\belowdisplayshortskip  6pt plus 3pt minus 3pt
\def\@listi{\parsep 3pt plus 2pt minus 1pt
            \itemsep \parsep
            \topsep 6pt plus 2pt minus 2pt}}

\renewcommand{\footnotesize}{
\@setfontsize\footnotesize\@ixpt{11}%
\abovedisplayskip 8pt plus 2pt minus 4pt%
\belowdisplayskip \abovedisplayskip
\abovedisplayshortskip  \z@ plus 3pt%
\belowdisplayshortskip  4pt plus 2pt minus 2pt
\def\@listi{\topsep 4pt plus 2pt minus 2pt\parsep 2pt plus 1pt minus 1pt
\itemsep \parsep}}

\renewcommand{\scriptsize}{\@setfontsize\scriptsize\@viiipt{9.5}}
\renewcommand{\tiny}{\@setfontsize\tiny\@vipt\@viipt}
\renewcommand{\large}{\@setfontsize\large\@xiipt{14}}
\renewcommand{\Large}{\@setfontsize\Large\@xivpt{18}}
\renewcommand{\LARGE}{\@setfontsize\LARGE\@xviipt{22}}
\renewcommand{\huge}{\@setfontsize\huge\@xxpt{25}}
\renewcommand{\Huge}{\@setfontsize\Huge\@xxvpt{30}}

\else %Times New Roman 12pt

\renewcommand{\normalsize}{
\@setfontsize\normalsize\@xiipt{14.5}%
\abovedisplayskip 12pt plus 3pt minus 7pt%
\belowdisplayskip \abovedisplayskip
\abovedisplayshortskip  \z@ plus 3pt%
\belowdisplayshortskip  6.5pt plus 3.5pt minus 3pt}

\renewcommand{\small}{
\@setfontsize\small\@xipt{13.6}%
\abovedisplayskip 11pt plus 3pt minus 6pt%
\belowdisplayskip \abovedisplayskip
\abovedisplayshortskip  \z@ plus 3pt%
\belowdisplayshortskip  6.5pt plus 3.5pt minus 3pt
\def\@listi{\parsep 4.5pt plus 2pt minus 1pt
            \itemsep \parsep
            \topsep 9pt plus 3pt minus 5pt}}

\renewcommand{\footnotesize}{
\@setfontsize\footnotesize\@xpt\@xiipt%
\abovedisplayskip 10pt plus 2pt minus 5pt%
\belowdisplayskip \abovedisplayskip
\abovedisplayshortskip  \z@ plus 3pt%
\belowdisplayshortskip  6pt plus 3pt minus 3pt
\def\@listi{\topsep 6pt plus 2pt minus 2pt\parsep 3pt plus 3pt minus 1pt
\itemsep \parsep}}

\renewcommand\scriptsize{\@setfontsize\scriptsize\@viiipt{9.5}}
\renewcommand{\tiny}{\@setfontsize\tiny\@vipt\@viipt}
\renewcommand{\large}{\@setfontsize\large\@xivpt{18}}
\renewcommand{\Large}{\@setfontsize\Large\@xviipt{22}}
\renewcommand{\LARGE}{\@setfontsize\LARGE\@xxpt{25}}
\renewcommand{\huge}{\@setfontsize\huge\@xxvpt{30}}
\let\Huge=\huge

\fi

%\usepackage{setspace}

\normalsize  % Choose the normalsize font.


%  ****************************************
%  *            PAGE LAYOUT               *
%  ****************************************
%
% All margin dimensions measured from a point one inch from top and side
% of page.

% SIDE MARGINS:

\if@twoside                 				% Values for two-sided printing:
\setlength{\oddsidemargin}{36pt}
\setlength{\evensidemargin}{0pt}
\setlength{\marginparwidth}{12pt}
\else                       				% Values for one-sided printing:
\setlength{\oddsidemargin}{36pt} 	% Note that \oddsidemargin = \evensidemargin
\setlength{\evensidemargin}{36pt}
\setlength{\marginparwidth}{12pt}
\fi

\setlength{\marginparsep}{12pt}   % Horizontal space between outer margin and
                                  % marginal note


% VERTICAL SPACING:

\setlength{\topmargin}{-12pt}   % Nominal distance from top of page to top of box containing running head.
\setlength{\headsep}{36pt}      % *** edge and blue line.  ******** Burak
\setlength{\headheight}{12pt}   %    Height of box containing running head.
%\headsep 15pt           %    Space between running head and text.
% \topskip = 10pt        %    '\baselineskip' for first line of page.
                         % Bottom of page:
\setlength{\footskip}{36pt}     %    Distance from baseline of box containing foot to baseline of last line of text.
 

% DIMENSION OF TEXT:

\setlength{\textheight}{665pt}   % Height of text (including footnotes and figures, excluding running head and foot).
\setlength{\textwidth}{417pt}      % Width of text line.

% FOOTNOTES:

\setlength{\footnotesep}{14pt}   % Height of strut placed at the beginning of every footnote
\skip\footins 8pt plus 2pt minus 4pt     % Space between last line of text and top of first footnote.

% FLOATS: (a float is something like a figure or table)
%
%  FOR FLOATS ON A TEXT PAGE:
%
%    ONE-COLUMN MODE OR SINGLE-COLUMN FLOATS IN TWO-COLUMN MODE:
\floatsep 14pt plus 2pt minus 4pt        % Space between adjacent floats moved
                                         % to top or bottom of text page.
\textfloatsep 20pt plus 2pt minus 4pt    % Space between main text and floats
                                         % at top or bottom of page.
\intextsep 14pt plus 4pt minus 4pt       % Space between in-text figures and
                                         % text.
                                         
%  FOR FLOATS ON A SEPARATE FLOAT PAGE OR COLUMN:
%    ONE-COLUMN MODE OR SINGLE-COLUMN FLOATS IN TWO-COLUMN MODE:
\@fptop 0pt plus 1fil    % Stretch at top of float page/column. (Must be
                         % 0pt plus ...)
\@fpsep 10pt plus 2fil    % Space between floats on float page/column.
\@fpbot 0pt plus 1fil    % Stretch at bottom of float page/column. (Must be
                         % 0pt plus ... )

% MARGINAL NOTES:
%
\setlength{\marginparpush}{7pt}       % Minimum vertical separation between two marginal notes.

  

%  ****************************************
%  *           PARAGRAPHING               *
%  ****************************************

\ifIndent
\setlength{\parindent}{2em}        % Width of paragraph indentation.
\setlength{\parskip}{0pt} 	       % No extra vertical space between paragraphs.
\else
\setlength{\parindent}{0em}        % No paragraph indentation.
\setlength{\parskip}{12pt} 	       % 12pt extra space between paragraphs.
\fi

\topsep 10pt plus 4pt minus 6pt    % Extra vertical space, in addition to
                                   % \parskip, added above and below list and
                                   % paragraphing environments.
\partopsep 3pt plus 2pt minus 2pt  % Extra vertical space, in addition to
                                   % \parskip and \topsep, added when user
                                   % leaves blank line before environment.
\itemsep 5pt plus 2.5pt minus 1pt  % Extra vertical space, in addition to
                                   % \parskip, added between list items.


% The following page-breaking penalties are defined

\@lowpenalty   51      % Produced by \nopagebreak[1] or \nolinebreak[1]
\@medpenalty  151      % Produced by \nopagebreak[2] or \nolinebreak[2]
\@highpenalty 301      % Produced by \nopagebreak[3] or \nolinebreak[3]

\@beginparpenalty -\@lowpenalty    % Before a list or paragraph environment.
\@endparpenalty   -\@lowpenalty    % After a list or paragraph environment.
\@itempenalty     -\@lowpenalty    % Between list items.

% \clubpenalty         % 'Club line'  at bottom of page.
% \widowpenalty        % 'Widow line' at top of page.
% \displaywidowpenalty % Math display widow line.
% \predisplaypenalty   % Breaking before a math display.
% \postdisplaypenalty  % Breaking after a math display.
% \interlinepenalty    % Breaking at a line within a paragraph.
% \brokenpenalty       % Breaking after a hyphenated line.

%    ****************************************
%    *        CHAPTERS AND SECTIONS         *
%    ****************************************
%

% \@makechapterhead {TEXT} : Makes the heading for the \chapter command.
%

\def\@makechapterhead#1{             % Heading for \chapter command
  { \parindent 0pt \raggedright
		\centering
  	\vskip 20pt 
  	\Large{\bf\@Roman{\thechapter}\space\uppercase{#1}}
  	\nobreak                         % TeX penalty to prevent page break.
  	\vskip 40pt                      % Space between title and text.
  	\vskip -\parskip								 % Remove extra spacing due to parskip.
  } }

% \@makeschapterhead {TEXT} : Makes the heading for the \chapter* command.
%

\def\@makeschapterhead#1{             % Heading for \chapter* command
  { \parindent 0pt \raggedright
    \centering
  	\vskip 20pt 
    \Large{\uppercase{#1}}\par
    \nobreak                         % TeX penalty to prevent page break.
  	\vskip 40pt                      % Space between title and text.
  	\vskip -\parskip								 % Remove extra spacing due to parskip.
  } }

% \secdef{UNSTARCMDS}{STARCMDS} :
%    When defining a \chapter or \section command without using
%    \@startsection, you can use \secdef as follows:
%       \def\chapter { ... \secdef \CMDA \CMDB }
%       \def\CMDA    [#1]#2{ ...   % Command to define \chapter[...]{...}
%       \def\CMDB    #1{ ...       % Command to define \chapter*{...}

\def\chapter{\clearpage      % Starts new page.
   \global\@topnum\z@        % Prevents figures from going at top of page.
   \@afterindentfalse        % Suppresses indent in first paragraph.  Change
	\thispagestyle{myheadingsnum} %Remove page numbering from chapter pages
   \secdef\@chapter\@schapter}   % to \@afterindenttrue to have indent.

\def\@chapter[#1]#2{\ifnum \c@secnumdepth >\m@ne
        \refstepcounter{chapter}
        \typeout{\@chapapp\space\thechapter.}
        \addcontentsline{toc}{chapter}{\protect
        \numberline{\thechapter}\texorpdfstring{\uppercase{#1}}{#1}}
      \else\addcontentsline{toc}{chapter}{#1}\fi
   \chaptermark{#1}
%   \addtocontents{lof}{\protect\addvspace{10pt}} % Adds between-chapter space
%   \addtocontents{lot}{\protect\addvspace{10pt}} % to lists of figs & tables.
			\@makechapterhead{\uppercase{#2}}
           \@afterheading 
}

\def\@schapter#1{
	\if@twocolumn \@topnewpage[\@makeschapterhead{#1}]
        \else \@makeschapterhead{#1}
              \@afterheading\fi}

% \@startsection {NAME}{LEVEL}{INDENT}{BEFORESKIP}{AFTERSKIP}{STYLE}
%            optional * [ALTHEADING]{HEADING}
%    Generic command to start a section.
%    NAME       : e.g., 'subsection'
%    LEVEL      : a number, denoting depth of section -- e.g., chapter=1,
%                 section = 2, etc.  A section number will be printed if
%                 and only if LEVEL < or = the value of the secnumdepth
%                 counter.
%    INDENT     : Indentation of heading from left margin
%    BEFORESKIP : Absolute value = skip to leave above the heading.
%                 If negative, then paragraph indent of text following
%                 heading is suppressed.
%    AFTERSKIP  : if positive, then skip to leave below heading,
%                       else - skip to leave to right of run-in heading.
%    STYLE      : commands to set style
%  If '*' missing, then increments the counter.  If it is present, then
%  there should be no [ALTHEADING] argument.  A sectioning command
%  is normally defined to \@startsection + its first six arguments.

%\z@ is shorthand for 0pt

% redefined to avoid parskip after section headings
\def\@xsect#1{%
  \@tempskipa #1\relax
  \ifdim \@tempskipa>\z@
    \par \nobreak
    \vskip \@tempskipa 
    \vskip -\parskip			%Remove spacing due to parskip
    \@afterheading
  \else
    \@nobreakfalse
    \global\@noskipsectrue
    \everypar{%
      \if@noskipsec
        \global\@noskipsecfalse
       {\setbox\z@\lastbox}%
        \clubpenalty\@M
        \begingroup \@svsechd \endgroup
        \unskip
        \@tempskipa #1\relax
        \hskip -\@tempskipa
      \else
        \clubpenalty \@clubpenalty
        \everypar{}%
      \fi}%
  \fi
  \ignorespaces}

\def\@startsection#1#2#3#4#5#6{%
  \if@noskipsec \leavevmode \fi
  \par 
  \@tempskipa #4\relax
  \@afterindenttrue
  \ifdim \@tempskipa <\z@
    \@tempskipa -\@tempskipa \@afterindentfalse
  \fi
  \if@nobreak
    \everypar{}%
  \else
    \addpenalty\@secpenalty\addvspace\@tempskipa\vskip -\parskip
  \fi
  \@ifstar
    {\@ssect{#3}{#4}{#5}{#6}}%
    {\@dblarg{\@sect{#1}{#2}{#3}{#4}{#5}{#6}}}}
   
\def\section{\@startsection{section}{1}{\z@}{-3.5ex plus -1ex minus -.2ex}{2.3ex plus .2ex}{\normalsize\bf\oneandhalfspace}}
\def\subsection{\@startsection{subsection}{2}{\z@}{-3.25ex plus -1ex minus -.2ex}{1.5ex plus .2ex}{\normalsize\bf\oneandhalfspace}}
\def\subsubsection{\@startsection{subsubsection}{2}{\z@}{-3.25ex plus -1ex minus -.2ex}{1.5ex plus .2ex}{\normalsize\bf\oneandhalfspace}}

% Disallow sectioning below \subsubsection.
\renewcommand\paragraph{\err@@illcmd\paragraph}
\renewcommand\subparagraph{\err@@illcmd\subparagraph}
%\def\paragraph{\@startsection{paragraph}{4}{\z@}{3.25ex plus 1ex minus .2ex}{-1em}{\normalsize\bf\oneandhalfspace}}
%\def\subparagraph{\@startsection{subparagraph}{4}{\parindent}{3.25ex plus 1ex minus .2ex}{-1em}{\normalsize\bf\oneandhalfspace}}

                    


%    *******************************************
%    *                APPENDIX                 *
%    *******************************************

\def\appendix#1{
	\clearpage      % Starts new page.
  \global\@topnum\z@        % Prevents figures from going at top of page.
  \@afterindentfalse        % Suppresses indent in first paragraph.  Change
	\@addtoreset{equation}{appendix}   % Makes \appendix reset 'equation' counter.
	\@addtoreset{figure}{appendix}   % Makes \appendix reset 'figure' counter.
	\@addtoreset{section}{appendix}   % Makes \appendix reset 'section' counter.
	\@addtoreset{subsection}{appendix}   % Makes \appendix reset 'subsection' counter.
	\@addtoreset{subsubsection}{appendix}   % Makes \appendix reset 'subsubsection' counter.
  \refstepcounter{appendix}
	\renewcommand{\thefigure}{\Alph{appendix}.\arabic{figure}.}
	\renewcommand{\thetable}{\Alph{appendix}.\arabic{table}.}
	\renewcommand{\thesection}{\Alph{appendix}.\arabic{section}.}
	\renewcommand{\thesubsection}{\Alph{appendix}.\arabic{section}.\arabic{subsection}.}
	\renewcommand{\thesubsubsection}{\Alph{appendix}.\arabic{section}.\arabic{subsection}.\arabic{subsubsection}.}
	\renewcommand{\theHfigure}{\Alph{appendix}.\arabic{figure}.}
	\renewcommand{\theHtable}{\Alph{appendix}.\arabic{table}.}
	\renewcommand{\theHsection}{\Alph{appendix}.\arabic{section}.}
	\renewcommand{\theHsubsection}{\Alph{appendix}.\arabic{section}.\arabic{subsection}.}
	\renewcommand{\theHsubsubsection}{\Alph{appendix}.\arabic{section}.\arabic{subsection}.\arabic{subsubsection}.}
%	\def\theequation{\Alph{appendix}.\arabic{equation}}
 	\vskip .2truein
	\ifEnglish
 	\centerline {\textbf{\large{APPENDIX \theappendix}}}
 	\addcontentsline{toc}{chapter}{APPENDIX \theappendix}
	\else
 	\centerline {\textbf{\large{EK \theappendix}}}
 	\addcontentsline{toc}{chapter}{EK \theappendix}
	\fi	
 	\bigskip
 	\begin{center} {\uppercase{#1}}
 	\end{center}
 	\nobreak\bigskip}

%    **********************************************************
%    *                LIMIT NUMBER OF SECTION                 *
%    **********************************************************

\setcounter{secnumdepth}{2}


%    ****************************************
%    *                LISTS                 *
%    ****************************************
%

% The following commands are used to set the default values for the list
% environment's parameters. See the LaTeX manual for an explanation of
% the meanings of the parameters.  Defaults for the list environment are
% set as follows.  First, \rightmargin, \listparindent and \itemindent
% are set to 0pt.  Then, for a Kth level list, the command \@listK is
% called, where 'K' denotes 'i', 'ii', ... , 'vi'.  (I.e., \@listiii is
% called for a third-level list.)  By convention, \@listK should set
% \leftmargin to \leftmarginK.
%
% For efficiency, level-one list's values are defined at top level, and
% \@listi is defined to set only \leftmargin.

\leftmargini 2.5em
\leftmarginii 2.2em     % > \labelsep + width of '(m)'
\leftmarginiii 1.87em   % > \labelsep + width of 'vii.'
\leftmarginiv 1.7em     % > \labelsep + width of 'M.'
\leftmarginv 1em
\leftmarginvi 1em

\leftmargin\leftmargini
\labelwidth\leftmargini\advance\labelwidth-\labelsep
\labelsep .5em
\parsep 5pt plus 2.5pt minus 1pt

\def\@listi{\leftmargin\leftmargini}

\def\@listii{\leftmargin\leftmarginii
   \labelwidth\leftmarginii\advance\labelwidth-\labelsep
   \topsep 5pt plus 2.5pt minus 1pt
   \parsep 2.5pt plus 1pt minus 1pt
   \itemsep \parsep}

\def\@listiii{\leftmargin\leftmarginiii
    \labelwidth\leftmarginiii\advance\labelwidth-\labelsep
    \topsep 2.5pt plus 1pt minus 1pt
    \parsep \z@ \partopsep 1pt plus 0pt minus 1pt
    \itemsep \topsep}

\def\@listiv{\leftmargin\leftmarginiv
     \labelwidth\leftmarginiv\advance\labelwidth-\labelsep}

\def\@listv{\leftmargin\leftmarginv
     \labelwidth\leftmarginv\advance\labelwidth-\labelsep}

\def\@listvi{\leftmargin\leftmarginvi
     \labelwidth\leftmarginvi\advance\labelwidth-\labelsep}


%    ****************************************
%    *                LISTS                 *
%    ****************************************
%

% ENUMERATE
%  Enumeration is done with four counters: enumi, enumii, enumiii
%  and enumiv, where enumN controls the numbering of the Nth level
%  enumeration.  The label is generated by the commands \labelenumi
%  ... \labelenumiv.  The expansion of \p@enumN\theenumN defines the
%  output of a \ref command.

\renewcommand{\labelenumi}{\arabic{enumi}.}
\renewcommand{\theenumi}{\arabic{enumi}}

\renewcommand{\labelenumii}{(\alph{enumii})}
\renewcommand{\theenumii}{\alph{enumii}}
\renewcommand{\p@enumii}{\theenumi}

\renewcommand{\labelenumiii}{\roman{enumiii}.}
\renewcommand{\theenumiii}{\roman{enumiii}}
\renewcommand{\p@enumiii}{\theenumi(\theenumii)}

\renewcommand{\labelenumiv}{\Alph{enumiv}.}
\renewcommand{\theenumiv}{\Alph{enumiv}}
\renewcommand{\p@enumiv}{\p@enumiii\theenumiii}

% ITEMIZE
% Itemization is controlled by four commands: \labelitemi, \labelitemii,
% \labelitemiii, and \labelitemiv, which define the labels of the various
% itemization levels.

%\renewcommand{\labelitemi}{$\bullet$}
%\renewcommand{\labelitemii}{\bf --}
%\renewcommand{\labelitemiii}{$\ast$}
%\renewcommand{\labelitemiv}{$\cdot$}

\renewcommand{\labelitemi}{\bf --}

%    ****************************************
%    *         OTHER ENVIRONMENTS           *
%    ****************************************
%

% ARRAY AND TABULAR
%

\setlength{\arraycolsep}{5pt}     % Half the space between columns in an array environment.
\setlength{\tabcolsep}{6pt}       % Half the space between columns in a tabular environment.
\setlength{\arrayrulewidth}{.4pt} % Width of rules in array and tabular environment.
\setlength{\doublerulesep}{2pt}   % Space between adjacent rules in array or tabular env.

% TABBING
%
\tabbingsep \labelsep   % Space used by the \' command.  (See LaTeX manual.)

% FRAMEBOX
%
\setlength{\fboxsep}{3pt}    % Space left between box and text by \fbox and \framebox.
\setlength{\fboxrule}{.4pt}  % Width of rules in box made by \fbox and \framebox.


%    ****************************************
%    *        CHAPTERS AND SECTIONS         *
%    ****************************************
%
% DEFINE COUNTERS:
%
% \newcounter{NEWCTR}[OLDCTR] : Defines NEWCTR to be a counter, which is
%                               reset to zero when counter OLDCTR is stepped.
%                               Counter OLDCTR must already be defined.

\newcounter {appendix}
%
% For any counter CTR, \theCTR is a macro that defines the printed version
% of counter CTR.  It is defined in terms of the following macros:
%
%  \arabic{COUNTER} : The value of COUNTER printed as an arabic numeral.
%  \roman{COUNTER}  : Its value printed as a lower-case roman numberal.
%  \Roman{COUNTER}  : Its value printed as an upper-case roman numberal.
%  \alph{COUNTER}   : Value of COUNTER printed as a lower-case letter:
%                         1 = a, 2 = b, etc.
%  \Alph{COUNTER}   : Value of COUNTER printed as an upper-case letter:
%                           1 = A, 2 = B, etc.
%

\renewcommand{\thechapter}       {\arabic{chapter}.}
\renewcommand{\thesection}       {\arabic{chapter}.\arabic{section}.}
\renewcommand{\thesubsection}    {\arabic{chapter}.\arabic{section}.\arabic{subsection}.}
\renewcommand{\thesubsubsection} {\arabic{chapter}.\arabic{section}.\arabic{subsection}.\arabic{subsubsection}.}
\renewcommand{\theparagraph}     {\null}
\renewcommand{\thesubparagraph}  {\null}
\renewcommand{\theappendix}      {\Alph{appendix}}

% \@chapapp is initially defined to be 'Chapter'.  The \appendix
% command redefines it to be 'Appendix'.
%
\def\@chapapp{CHAPTER}

%    ****************************************
%    *             BIBLIOGRAPHY             *
%    ****************************************
%
%
%  \def\newblock{\hskip .11em plus .33em minus -.07em} --
%      Defines the `closed' format, where the blocks (major units of
%      information) of an entry run together.
%
%  \sloppy  -- Used because it's rather hard to do line breaks in
%      bibliographies,
%
%  \sfcode`\.=1000\relax --
%      Causes a `.' (period) not to produce an end-of-sentence space.

\def\thebibliography#1{
\vskip .2truein
\ifEnglish
%\centerline{\textbf{\large{REFERENCES}}}
\chapter*{\textbf{\large{REFERENCES}}}
\addcontentsline{toc}{chapter}{REFERENCES}
\else
%\centerline{\textbf{\large{KAYNAKLAR}}}
\chapter*{\textbf{\large{KAYNAKLAR}}}
\addcontentsline{toc}{chapter}{KAYNAKLAR}
\fi
\bigskip
\list
  {[\arabic{enumi}]}{\settowidth\labelwidth{[#1]}\leftmargin\labelwidth
    \advance\leftmargin\labelsep
    \usecounter{enumi}}
    \def\newblock{\hskip .11em plus .33em minus -.07em}
    \sloppy
    \sfcode`\.=1000\relax}
\let\endthebibliography=\endlist

%    ****************************************
%    *              THE INDEX               *
%    ****************************************
%
% THE THEINDEX ENVIRONMENT
% Produces double column format, with each paragraph a separate entry.
% The user commands \item, \subitem and \subsubitem are used to
% produce the entries, and \indexspace adds an extra vertical space
% that's the right size to put above the first entry with a new letter
% of the alphabet.

\newif\if@restonecol

\def\theindex{\@restonecoltrue\if@twocolumn\@restonecolfalse\fi
\columnseprule \z@
\columnsep 35pt\twocolumn[\@makeschapterhead{Index}]
    \markboth{INDEX}{INDEX}\thispagestyle{plain}\parindent\z@
    \parskip\z@ plus .3pt\relax\let\item\@idxitem}

\def\@idxitem{\par\hangindent 40pt}

\def\subitem{\par\hangindent 40pt \hspace*{20pt}}

\def\subsubitem{\par\hangindent 40pt \hspace*{30pt}}

\def\endtheindex{\if@restonecol\onecolumn\else\clearpage\fi}

\def\indexspace{\par \vskip 10pt plus 5pt minus 3pt\relax}


%    ****************************************
%    *             FOOTNOTES                *
%    ****************************************
%
% \footnoterule is a macro to draw the rule separating the footnotes from
% the text.  It should take zero vertical space, so it needs a negative
% skip to compensate for any positive space taken by the rule.  (See
% PLAIN.TEX.)

\def\footnoterule{\kern-1\p@
  \hrule width .125\columnwidth
  \kern .6\p@}                 % The \hrule has default height of .4pt .

\@addtoreset{footnote}{chapter}  % Numbers footnotes within chapters
\@addtoreset{footnote}{appendix}  % Numbers footnotes within appendix

%   \@makefntext{NOTE} :
%        Must produce the actual footnote, using \@thefnmark as the mark
%        of the footnote and NOTE as the text.  It is called when effectively
%        inside a \parbox of width \columnwidth (i.e., with \hsize =
%        \columnwidth).
%
%        The following macro indents all lines of the footnote by 10pt, and
%        indents the first line of a new paragraph by 1em.  To change these
%        dimensions, just substitute the desired value for '10pt' [in both
%        places] or '1em'.  The mark is flushright against the footnote.
%          \long\def\@makefntext#1{\@setpar{\@@par\@tempdima \hsize
%             \advance\@tempdima-10pt\parshape \@ne 10pt \@tempdima}\par
%             \parindent 1em\noindent \hbox to \z@{\hss$^{\@thefnmark}$}#1}
%
%        A simpler macro is used, in which the footnote text is
%        set like an ordinary text paragraph, with no indentation except
%        on the first line of a paragraph, and the first line of the
%        footnote.  Thus, all the macro must do is set \parindent
%        to the appropriate value for succeeding paragraphs and put the
%        proper indentation before mark.

\long\def\@makefntext#1{\parindent 1em\noindent
            \hbox to 1.8em{\hss$^{\@thefnmark}$}#1}


%    ****************************************
%    *         FIGURES AND TABLES           *
%    ****************************************
%
% Float placement parameters.  See LaTeX manual for their definition.
%
\setcounter{topnumber}{2}
\renewcommand{\topfraction}{.7}
\setcounter{bottomnumber}{1}
\renewcommand{\bottomfraction}{.3}
\setcounter{totalnumber}{3}
\renewcommand{\textfraction}{.2}
\renewcommand{\floatpagefraction}{.5}
\setcounter{dbltopnumber}{2}
\renewcommand{\dbltopfraction}{.7}
\renewcommand{\dblfloatpagefraction}{.5}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%   Long Captions --  this is a slightly modified \caption to allow just
%                     the first sentence on a very long caption to be
%                     written on the lof/lot
%
%   \longcaption{sentence 1}{rest of caption}
%
%   only 'sentence 1' will be written to the lof/lot as appropriate.
%   'sentence 1' and 'rest of caption' will be written together to the
%   figure/table caption. --Todd
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%  \@dblarg{CMD}{ARG}  : \@dblarg{CMD}{ARG} expands to CMD[ARG]{ARG}.  Use
%                        \@dblarg\CS when \CS takes arguments [ARG1]{ARG2}, 
%                        where default is ARG1 = ARG2.
%
% \def\caption{\refstepcounter\@captype \@dblarg{\@caption\@captype}}


\def\longcaption{\refstepcounter\@captype \@longcaption\@captype}

\long\def\@longcaption#1#2#3{\par\addcontentsline{\csname
  ext@#1\endcsname}{#1}{\protect\numberline{\csname 
  the#1\endcsname}{\ignorespaces #2}}\begingroup
    \@parboxrestore
    \normalsize
    \@makecaption{\csname fnum@#1\endcsname}{\ignorespaces #2 #3}\par
  \endgroup}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%   Multiline Fig. captions --  calculated the width of "Fig. ##. "
%   and use that to indent the caption so all lines will allign under the
%   first letter of the caption rather than against the right margin.
%
%   Fig. ##.  Long caption ....
%             Start of second line....
%             third line ...  etc.
%   --Todd
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% \@makecaption{NUMBER}{TEXT} : Macro to make a figure or table caption.
%      NUMBER : Figure or table number--e.g., 'Figure 3.2'
%      TEXT   : The caption text.
%  Macro should be called inside a \parbox of right width, with \normalsize.

\def\captionspace{\baselineskip=18pt} 
\long\def\@makecaption#1#2{       
   \vskip 12pt 
   \setbox\@tempboxa\hbox{#1 #2}  %  
   \ifdim \wd\@tempboxa >\hsize   %  IF longer than one line:
      \captionspace               %   THEN measure the width of "Fig. ##. "
      \setbox\@tempboxa\hbox{#1}  %       we'll indent the entire TEXT portion
      \hangindent=\wd\@tempboxa   %       of the caption by this amount.
      \hangafter=0                %       The Fig. num. is typeset as a negative
                                  %       width hbox to cancel the \hangindent
                                  %       on the first line. This the only way
                                  %       I could line things up without
                                  %       messing with tex glue.
      \setbox\@tempboxa\hbox{\llap{#1 }#2}
      \unhbox\@tempboxa\par        %       set TEXT as an ordinary paragraph
      \doublespace                % 
     \else                        %  ELSE  center.
       \hbox to\hsize{\hfil\box\@tempboxa\hfil}
   \fi
   \vskip 12pt 
}

% To define a float of type TYPE (e.g., TYPE = figure), the document style
% must define the following.
%
%  \fps@TYPE   : The default placement specifier for floats of type TYPE.
%
%  \ftype@TYPE : The type number for floats of type TYPE.  Each TYPE has
%                associated a unique positive TYPE NUMBER, which is a power
%                of two.  E.g., figures might have type number 1, tables type
%                number 2, programs type number 4, etc.
%
%  \ext@TYPE   : The file extension indicating the file on which the
%                contents list for float type TYPE is stored.  For example,
%                \ext@figure = 'lof'.
%
%  \fnum@TYPE  : A macro to generate the figure number for a caption.
%                For example, \fnum@TYPE == Figure \thefigure.
%
%  The actual float-making environment commands--e.g., the commands
%  \figure and \endfigure--are defined in terms of the macros \@float
%  and \end@float, which are described below.
%
%  \@float{TYPE}[PLACEMENT] : Macro to begin a float environment for a
%     single-column float of type TYPE with PLACEMENT as the placement
%     specifier.  The default value of PLACEMENT is defined by \fps@TYPE.
%     The environment is ended by \end@float.
%     E.g., \figure == \@float{figure}, \endfigure == \end@float.


%    *****************************
%    *         FIGURES           *
%    *****************************

\renewcommand{\thefigure}{\thechapter\arabic{figure}.}
\renewcommand{\thesubfigure}{(\alph{subfigure})}
\def\p@subfigure{\thechapter\arabic{figure}}
\def\fps@figure{tbp}
\def\ftype@figure{1}
\def\ext@figure{lof}
\ifEnglish
\def\fnum@figure{Fig.\ \thefigure}
\else
\def\fnum@figure{\c{S}ekil \thefigure}
\fi
\def\figure{\@float{figure}}
\let\endfigure\end@float
\@namedef{figure*}{\@dblfloat{figure}}
\@namedef{endfigure*}{\end@dblfloat}

%    ****************************
%    *         TABLES           *
%    ****************************

\renewcommand{\thetable}{\thechapter\arabic{table}.}
\def\fps@table{tbp}
\def\ftype@table{2}
\def\ext@table{lot}
\ifEnglish
\def\fnum@table{Table \thetable}
\else
\def\fnum@table{Tablo \thetable}
\fi
\def\table{\@float{table}}
\let\endtable\end@float
\@namedef{table*}{\@dblfloat{table}}
\@namedef{endtable*}{\end@dblfloat}


%    ****************************************
%    *         TITLE AND ABSTRACT           *
%    ****************************************
%
%
% Parameters used in Title definitions

\newcommand{\fact}{Engineering and Architecture}	% Change if you are not in Engineering and Architecture
\newcommand{\dept}{Electrical and Electronics Engineering} % Sets default department to be Electrical and Electronics Engineering
\newcommand{\prog}{Electrical and Electronic Engineering}	% Sets default program to be Electrical and Electronics Engineering
\newcommand{\student}{Your Full Name} % Sets student name
\newcommand{\titlee}{First Line of Title\\ Second Line of Title} % Sets title
\newcommand{\titlet}{\.{I}lk Sat{\i}r \\ \.{I}kinci Sat{\i}r } % Trke nszn ismi
\newcommand{\titlepdf}{First Line of Title Second Line of Title} % Sets title for pdf document properties
\newcommand{\keywords}{Keywords} % Sets keywords
\newcommand{\anahtarkelimeler}{Anahtar Kelimeler} % Turkce nszdeki Anahtar Kelimeler
%\def\chair{Chair Name}	% Chair Name
%\def\cochair{Co-Chair Name}	% Co-Chair Name
%\def\membera{Member Name}	% Member Name
%\def\memberb{Member Name}	% Member Name
%\def\memberc{Member Name}	% Member Name
%\def\memberd{Member Name}	% Member Name
\newcommand{\dean}{Dean Name}	%Dean Name
\newcommand{\monthyear}{Month Year}	%Thesis Year

\newcolumntype{C}[1]{>{\centering\let\newline\\\arraybackslash\hspace{0pt}}p{#1}}
\newcolumntype{D}[1]{>{\vbox to 2cm\bgroup\centering}p{#1}<{\egroup}}  


%    ********************************
%    *         TITLE PAGE           *
%    ********************************

\def\maketitlepage{
	\begin{titlepage}
	\parindent 0pt
	\parskip 0pt
	\doublespace %set double space
	\let\footnotesize\small       % Local definitions to make \thanks produce
 	\let\footnoterule\relax       % \normalsize footnotes with no separating rule.
	\pagenumbering{roman}
 	\setcounter{page}{0}
 	\null
 	\vfil
 	\vskip 5truept                % To adjust centering.
 	\begin{center}
  \vskip -2em                 % Adjust vertical position. 
	\ifEnglish
		\ifBSC
		   {FACULTY OF ENGINEERING\par}       % Set Faculty in \normal size.
		   {\MakeTextUppercase{DEPARTMENT OF \dept}\par}       % Set Department in \normal size.
		\fi
		\ifMSC
		   {INSTITUTE OF NATURAL AND APPLIED SCIENCES\par}       % Set Faculty in \normal size.
		   %{\MakeTextUppercase{DEPARTMENT OF \dept}\par}       % Set Department in \normal size.
		\fi
		\ifPHD
		   {INSTITUTE OF NATURAL AND APPLIED SCIENCES\par}       % Set Faculty in \normal size.
		   %{\MakeTextUppercase{DEPARTMENT OF \dept}\par}       % Set Department in \normal size.
		\fi
	\else
		\ifBSC
		   {\MakeTextUppercase{M\"{U}HEND\.{I}SL\.{I}K FAK\"{U}LTES\.{I}}\par}       % Set Faculty in \normal size.
		   {\MakeTextUppercase{\dept\space B\"{O}L\"{U}M\"{U}} \par}       % Set Department in \normal size.
		\fi
		\ifMSC
		   {\MakeTextUppercase{FEN B\.{I}L\.{I}MLER\.{I} ENST\.{I}T\"{U}S\"{U}}\par}       % Set Faculty in \normal size.
		   %{\MakeTextUppercase{\dept\space ANAB\.{I}L\.{I}M DALI} \par}       % Set Department in \normal size.
		\fi
		\ifPHD
		   {\MakeTextUppercase{FEN B\.{I}L\.{I}MLER\.{I} ENST\.{I}T\"{U}S\"{U}}\par}       % Set Faculty in \normal size.
		   %{\MakeTextUppercase{\dept\space ANAB\.{I}L\.{I}M DALI}\par}       % Set Department in \normal size.
		\fi
	\fi
  \vskip 4em                % Vertical space after Department.
	\includegraphics[trim=8.96cm 8.22cm 8.96cm 0cm,clip=true,width=50mm]{okan_logo}% Add Okan Logo.
  \vskip 3em                 % Adjust vertical position. 
	\ifEnglish
		{\uppercase{\titlee} \par}       % Set title in \normal size.
	\else
		{\uppercase{\titlet} \par}       % Set title in \normal size.
	\fi
  \vskip 2em                 % Adjust vertical position. 
  {\lineskip .75em            % Author  
  \begin{tabular}[t]{c} 
	\ifEnglish
		 A
		\ifBSC
		     \MakeTextUppercase{GRADUATION PROJECT}
		\fi
		\ifMSC
		     \MakeTextUppercase{THESIS}
		\fi
		\ifPHD
		     \MakeTextUppercase{DISSERTATION}
		\fi
     \\[1em] submitted by\\[1em] \MakeTextUppercase{\student}\\[1em] \\[1em]
     in partial fulfillment of the requirements for the degree of \\[1em]
		\ifBSC
		     \MakeTextUppercase{BACHELOR OF SCIENCE}
		\fi
		\ifMSC
		     \MakeTextUppercase{MASTER OF SCIENCE}
		\fi
		\ifPHD
		     \MakeTextUppercase{DOCTOR OF PHILOSOPHY}
		\fi
		\\[1em]\\
	\else
		\ifBSC
		     \MakeTextUppercase{B\.{I}T\.{I}RME PROJES\.{I}}
		\fi
		\ifMSC
		     \MakeTextUppercase{Y\"{U}KSEK L\.{I}SANS TEZ\.{I}}
		\fi
		\ifPHD
		     \MakeTextUppercase{DOKTORA TEZ\.{I}}
		\fi
     \\[1em] \\[1em] \MakeTextUppercase{\student}\\[1em] \\[1em]
     taraf{\i}ndan  \\[1em]
		\ifBSC
		     \MakeTextUppercase{L\.{I}SANS}
		\fi
		\ifMSC
		     \MakeTextUppercase{Y\"{U}KSEK L\.{I}SANS}
		\fi
		\ifPHD
		     \MakeTextUppercase{DOKTORA}
		\fi
		\\[1em]derecesi \c{s}art{\i}n{\i} sa\u{g}lamak i\c{c}in haz{\i}rlanm{\i}\c{s}t{\i}r.
	\fi	
  \end{tabular}\par}      
  \vskip 4em                  % Vertical space
  {\monthyear \par}           % Date
  \vskip 1.5em                  % Vertical space
  {Program: \prog}
\end{center} \par
\@thanks
%\vfil
%\null
\end{titlepage}
\setcounter{footnote}{0}       % Footnotes start at zero again.
\let\thanks\relax
\gdef\@thanks{}\gdef\@author{}\gdef\@title{}\let\maketitlepage\relax}

%    **************************************
%    *         HARDCOVER TITLE            *
%    **************************************

\def\makehardcovertitle{
	\begin{adjustwidth}{-36pt}{}
	\parindent 0pt
	\parskip 0pt
	\doublespace %set double space
	\let\footnotesize\small       % Local definitions to make \thanks produce
 	\let\footnoterule\relax       % \normalsize footnotes with no separating rule.
	\pagenumbering{roman}
 	\setcounter{page}{0}
 	\null
 	\vfil
 	\vskip 5truept                % To adjust centering.
 	\begin{center}
  \vskip -2em                 % Adjust vertical position. 
	\ifEnglish
		\ifBSC
		   {FACULTY OF ENGINEERING\par}       % Set Faculty in \normal size.
		   {\MakeTextUppercase{DEPARTMENT OF \dept}\par}       % Set Department in \normal size.
		\fi
		\ifMSC
		   {INSTITUTE OF NATURAL AND APPLIED SCIENCES\par}       % Set Faculty in \normal size.
		   {\MakeTextUppercase{DEPARTMENT OF \dept}\par}       % Set Department in \normal size.
		\fi
		\ifPHD
		   {INSTITUTE OF NATURAL AND APPLIED SCIENCES\par}       % Set Faculty in \normal size.
		   {\MakeTextUppercase{DEPARTMENT OF \dept}\par}       % Set Department in \normal size.
		\fi
	\else
		\ifBSC
		   {\MakeTextUppercase{M\"{U}HEND\.{I}SL\.{I}K FAK\"{U}LTES\.{I}}\par}       % Set Faculty in \normal size.
		   {\MakeTextUppercase{\dept\space B\"{O}L\"{U}M\"{U}} \par}       % Set Department in \normal size.
		\fi
		\ifMSC
		   {\MakeTextUppercase{FEN B\.{I}L\.{I}MLER\.{I} ENST\.{I}T\"{U}S\"{U}}\par}       % Set Faculty in \normal size.
		   {\MakeTextUppercase{\dept\space ANAB\.{I}L\.{I}M DALI} \par}       % Set Department in \normal size.
		\fi
		\ifPHD
		   {\MakeTextUppercase{FEN B\.{I}L\.{I}MLER\.{I} ENST\.{I}T\"{U}S\"{U}}\par}       % Set Faculty in \normal size.
		   {\MakeTextUppercase{\dept\space ANAB\.{I}L\.{I}M DALI}\par}       % Set Department in \normal size.
		\fi
	\fi
  \vskip 6em                % Vertical space after Department.
	\ifEnglish
		{\uppercase{\titlee} \par}       % Set title in \normal size.
	\else
		{\uppercase{\titlet} \par}       % Set title in \normal size.
	\fi
  \vskip 6em                 % Adjust vertical position. 
  {\lineskip .75em            % Author  
  \begin{tabular}[t]{c} 
	\ifEnglish
		\ifBSC
		     \MakeTextUppercase{BACHELOR OF SCIENCE}\\[4em]
		     \MakeTextUppercase{GRADUATION PROJECT}
		\fi
		\ifMSC
		     \MakeTextUppercase{MASTER OF SCIENCE}\\[4em]
		     \MakeTextUppercase{THESIS}
		\fi
		\ifPHD
		     \MakeTextUppercase{DOCTOR OF PHILOSOPHY}\\[4em]
		     \MakeTextUppercase{DISSERTATION}
		\fi
	\else
		\ifBSC
		     \MakeTextUppercase{L\.{I}SANS}\\[4em]
		     \MakeTextUppercase{B\.{I}T\.{I}RME PROJES\.{I}}
		\fi
		\ifMSC
		     \MakeTextUppercase{Y\"{U}KSEK L\.{I}SANS}\\[4em]
		     \MakeTextUppercase{Y\"{U}KSEK L\.{I}SANS TEZ\.{I}}
		\fi
		\ifPHD
		     \MakeTextUppercase{DOKTORA}\\[4em]
		     \MakeTextUppercase{DOKTORA TEZ\.{I}}
		\fi
	\fi	
     \\[6em] \MakeTextUppercase{\student}\\[6em]
  
	\ifEnglish
	  SUPERVISOR: \MakeTextUppercase{\chair}\\
  \else
	  DANI\c{S}MAN: \MakeTextUppercase{\chair}\\
  \fi
  \end{tabular}\par}      
  \vskip 4em                  % Vertical space
  {\MakeTextUppercase{\monthyear} \par}           % Date
  \vskip 2em                  % Vertical space
  {PROGRAM: \MakeTextUppercase{\prog}}
\end{center} \par
\@thanks
\end{adjustwidth}
}

%    ***********************************
%    *         APPROVAL PAGE           *
%    ***********************************

\def\approval{
	\newpage
	\parskip 0pt
	\parskip 0pt
	\doublespace
	\pagestyle{empty}
	\pagenumbering{roman}
	\setcounter{page}{1}
	\ifEnglish
	\currentpdfbookmark{APPROVAL}{APPROVAL}
	\else
	\currentpdfbookmark{ONAY}{ONAY}
	\fi
%	\null\vfill
%	\vskip -6em
	\begin{center}
	\ifEnglish
		{\uppercase{\titlee} \par}       % Set title in \normal size.
	\else
		{\uppercase{\titlet} \par}       % Set title in \normal size.
	\fi
  \vskip 2em % Vertical space
  {\lineskip .75em
  \begin{tabular}[t]{c} 
	\ifEnglish
  A 
	\ifBSC
	     \MakeTextUppercase{GRADUATION PROJECT}
	\fi
	\ifMSC
	     \MakeTextUppercase{THESIS}
	\fi
	\ifPHD
	     \MakeTextUppercase{DISSERTATION}
	\fi
	\\[1em] by\\[1em] \MakeTextUppercase{\student}
  \end{tabular}\par}      
  \vskip 2em % Vertical space
	\ifBSC
		{submitted to the Department of \dept\space of\\OKAN UNIVERSITY
		 \\[1em] in partial fulfillment of the requirements for the degree of \\\MakeTextUppercase{
				 \MakeTextUppercase{BACHELOR OF SCIENCE}
		}\smallskip}
	\fi
	\ifMSC
		{submitted to the Institute of Natural and Applied Sciences of\\OKAN UNIVERSITY
		 \\[1em] in partial fulfillment of the requirements for the degree of \\\MakeTextUppercase{
				 \MakeTextUppercase{MASTER OF SCIENCE}
		}\smallskip}
	\fi
	\ifPHD
		{submitted to the Institute of Natural and Applied Sciences of\\OKAN UNIVERSITY
		 \\[1em] in partial fulfillment of the requirements for the degree of \\\MakeTextUppercase{
				 \MakeTextUppercase{DOCTOR OF PHILOSOPHY}
		}\smallskip}
	\fi
	\vskip 1em    % Vertical space
	Approved by:
	\end{center}
	\vskip 4em
	{\singlespace

	\begin{tabular}{D{5cm} D{2cm} D{5cm}}
	\cline{1-1}\ifdefined\cochair\cline{3-3}\fi\oneandhalfspace
	\chair\par Supervisor&	&\ifdefined\cochair Co-Supervisor\fi\tabularnewline
	\ifdefined\membera\cline{1-1}\fi\ifdefined\memberb\cline{3-3}\fi\oneandhalfspace
	\ifdefined\membera\membera\par Member\fi& &\ifdefined\memberb \memberb\par Member\fi\tabularnewline
	\ifdefined\memberc\cline{1-1}\fi\ifdefined\memberd\cline{3-3}\fi\oneandhalfspace
	\ifdefined\memberc\memberc\par Member\fi& &\ifdefined\memberd\memberd\par Member\fi\tabularnewline
	\end{tabular}

\else
		\ifBSC
		     \MakeTextUppercase{B\.{I}T\.{I}RME PROJES\.{I}}
		\fi
		\ifMSC
		     \MakeTextUppercase{Y\"{U}KSEK L\.{I}SANS TEZ\.{I}}
		\fi
		\ifPHD
		     \MakeTextUppercase{DOKTORA TEZ\.{I}}
		\fi
	\\[1em] \MakeTextUppercase{\student}\\[1em] {taraf{\i}ndan}
  \end{tabular}\par}
  \vskip 1.8em % Vertical space
  {OKAN \"{U}N\.{I}VERS\.{I}TES\.{I}
   \\\dept\space 
	\ifBSC
			 B\"{o}l\"{u}m\"{u}ne \\[1em]
	     \MakeTextUppercase{L\.{I}SANS}
	\fi
	\ifMSC
			 Anabilim Dal{\i}na \\[1em]
	     \MakeTextUppercase{Y\"{U}KSEK L\.{I}SANS}
	\fi
	\ifPHD
			 Anabilim Dal{\i}na \\[1em]
	     \MakeTextUppercase{DOKTORA}
	\fi
  \\derecesi \c{s}art{\i}n{\i} sa\u{g}lamak i\c{c}in sunulmu\c{s}tur.}
	\vskip 1em    % Vertical space
	Onaylayan:
	\end{center}
	\vskip 4em
	{\singlespace

	\begin{tabular}{D{5cm} D{2cm} D{5cm}}
	\cline{1-1}\ifdefined\cochair\cline{3-3}\fi\oneandhalfspace
	\chair\par Dan{\i}\c{s}man&	&\ifdefined\cochair E\c{s}-Dan{\i}\c{s}man\fi\tabularnewline
	\ifdefined\membera\cline{1-1}\fi\ifdefined\memberb\cline{3-3}\fi\oneandhalfspace
	\ifdefined\membera\membera\par \"{U}ye\fi& &\ifdefined\memberb \memberb\par \"{U}ye\fi\tabularnewline
	\ifdefined\memberc\cline{1-1}\fi\ifdefined\memberd\cline{3-3}\fi\oneandhalfspace
	\ifdefined\memberc\memberc\par \"{U}ye\fi& &\ifdefined\memberd\memberd\par \"{U}ye\fi\tabularnewline
	\end{tabular}
	
\fi
	\vskip 2em
	\centerline{\monthyear}
	\vskip 1.5em
	\centerline{Program: \prog}}
	\vfill
	\newpage

\ifIndent
\setlength{\parindent}{2em}        % Width of paragraph indentation.
\setlength{\parskip}{0pt} 	       % No extra vertical space between paragraphs.
\else
\setlength{\parindent}{0em}        % No paragraph indentation.
\setlength{\parskip}{12pt} 	       % 12pt extra space between paragraphs.
\fi

}

%    ***********************************
%    *         ABSTRACT PAGE           *
%    ***********************************

\long\def\abseng#1{
\newpage\pagestyle{myheadings}
\begin{center}
\currentpdfbookmark{ABSTRACT}{ABSTRACT}
\textbf{\large{ABSTRACT}}
\vskip 1em
\normalsize\doublespace{\titlee}
\vskip 1em
\vskip -\parskip
\end{center}
\doublespace
#1
\vskip 9em
Keywords: \keywords
}

%    *******************************
%    *         ZET PAGE           *
%    *******************************

\long\def\abstur#1{
\newpage\pagestyle{myheadings}
\currentpdfbookmark{KISA \"{O}ZET}{KISA OZET}
\begin{center}
\textbf{\large{KISA \"{O}ZET}}
\vskip 1em
\normalsize\doublespace{\titlet}
\vskip 1em
\vskip -\parskip
\end{center}
#1
\vskip 9em
Anahtar Kelimeler: \anahtarkelimeler
}

%    *************************************
%    *         DEDICATION PAGE           *
%    *************************************

\def\dedicate#1{\newpage
\ifEnglish
\currentpdfbookmark{DEDICATION}{DEDICATION}
\else
\currentpdfbookmark{ARMA\u{G}AN}{ARMAGAN}
\fi
\null\vskip 7.5em
\begin{center}
\ifEnglish
To #1
\else
#1
\fi
\end{center}
\indent}


%    *****************************************
%    *         ACKNOWLEDGMENT PAGE           *
%    *****************************************

\def\acknow{\newpage
\vskip .2truein
\ifEnglish
\currentpdfbookmark{ACKNOWLEDGMENTS}{ACKNOWLEDGMENTS}
\centerline{\textbf{\large{ACKNOWLEDGMENTS}}}
\else
\currentpdfbookmark{\"{O}NS\"{O}Z}{ONSOZ}
\centerline{\textbf{\large{\"{O}NS\"{O}Z}}}
\fi
\vskip .3truein
\vskip -\parskip
\indent}


%    **********************************
%    *         SYMBOLS PAGE           *
%    **********************************

\def\symb{\newpage
\vskip .2truein
\ifEnglish
\chapter*{\textbf{\large{SYMBOLS}}}
\addcontentsline{toc}{chapter}{SYMBOLS}
\else
\chapter*{\textbf{\large{S\.{I}MGELER}}}
\addcontentsline{toc}{chapter}{S\.{I}MGELER}
\fi
\thispagestyle{myheadings}
\indent}

%    ***********************************
%    *         ACRONYMS PAGE           *
%    ***********************************

\def\acr{\newpage
\vskip .2truein
\ifEnglish
\chapter*{\textbf{\large{ACRONYMS}}}
\addcontentsline{toc}{chapter}{ACRONYMS}
\else
\chapter*{\textbf{\large{KISALTMALAR}}}
\addcontentsline{toc}{chapter}{KISALTMALAR}
\fi
\thispagestyle{myheadings}
\indent}

%    ****************************************
%    *         TABLE OF CONTENTS, ETC.      *
%    ****************************************
%
% A \subsection command writes a
%       \contentsline{subsection}{TITLE}{PAGE}
% command on the .toc file, where TITLE contains the contents of the
% entry and PAGE is the page number.  If subsections are being numbered,
% then TITLE will be of the form
%       \numberline{NUM}{HEADING}
% where NUM is the number produced by \thesubsection.  Other sectioning
% commands work similarly.
%
% A \caption command in a 'figure' environment writes
%    \contentsline{figure}{\numberline{NUM}{CAPTION}}{PAGE}
% on the .lof file, where NUM is the number produced by \thefigure and
% CAPTION is the figure caption.  It works similarly for a 'table' environment.
%
% The command \contentsline{NAME} expands to \l@NAME.  So, to specify
% the table of contents, we must define \l@chapter, \l@section,
% \l@subsection, ... ; to specify the list of figures, we must define
% \l@figure; and so on.  Most of these can be defined with the
% \@dottedtocline command, which works as follows.
%
% \@dottedtocline{LEVEL}{INDENT}{NUMWIDTH}{TITLE}{PAGE}
%    LEVEL    : An entry is produced only if LEVEL < or = value of
%               'tocdepth' counter.  Note, \chapter is level 0, \section
%               is level 1, etc.
%    INDENT   : The indentation from the outer left margin of the start of
%               the contents line.
%    NUMWIDTH : The width of a box in which the section number is to go,
%               if TITLE includes a \numberline command.
%
% This command uses the following three parameters, which are set
% with a \def (so em's can be used to make them depend upon the font).
%   \@pnumwidth : The width of a box in which the page number is put.
%   \@tocrmarg  : The right margin for multiple line entries.  One
%                 wants \@tocrmarg > or = \@pnumwidth
%   \@dotsep    : Separation between dots, in mu units.  Should be \def'd to
%                 a number like 2 or 1.7

\def\@pnumwidth{1.5em}
\def\@tocrmarg{4.5em}
\def\@dotsep{4.5}
\setcounter{tocdepth}{3}


% TABLEOFCONTENTS
%  In report style, \tableofcontents, figures, etc. are always
%  set in single-column style.  @restonecol

\newdimen\toddhack
\newdimen\twoem \twoem 0em
\newdimen\zeroem \zeroem 0em
\newdimen\fignumbox \fignumbox 4em

\def\tocnumflushright{
\twoem 2em
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%   The justification of the chapter heads is on the left side instead of
%   the right
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%   The macro below controls how the box is formed.  
%\def\numberline#1{\hbox to\@tempdima{#1\hfil}}
\def\numberline##1{\hbox to\@tempdima{\hfil##1\hskip 2ex\hskip \toddhack}}
%   these control the spacing from the left margin
%   #1 is the indentation level at which an entry is produced in the toc file
%   #2 is the total indentation from the left margin
%   #3 is the width of the box containing the chapter/section number
%

\def\l@chapter##1##2{\pagebreak[3]
\vskip 0.75em plus 1pt 
{\leftskip 0em\relax \rightskip \@tocrmarg \parfillskip -\rightskip
\parindent 0em\relax\@afterindenttrue
\interlinepenalty\@M
\leavevmode
\@tempdima 4em \toddhack 1em \relax
\advance\leftskip \@tempdima \hbox{}\hskip -\leftskip
\uppercase{##1}\nobreak\leaders\hbox{$\m@th \mkern \@dotsep mu.\mkern
\@dotsep mu$}\hfill \nobreak \hbox to\@pnumwidth{\hfil\rm ##2}\par}
\vskip 0.5em plus 1pt\toddhack 0em}

\def\l@section{\@dottedtocline{1}{7em}{3em}}
\def\l@subsection{\@dottedtocline{2}{9em}{3em}}
\def\l@subsubsection{\@dottedtocline{3}{11em}{3em}}
\def\l@paragraph{\@dottedtocline{4}{13em}{3em}}
\def\l@subparagraph{\@dottedtocline{5}{14em}{3em}}
} %

\def\tableofcontents{
	\newpage
	\parskip 0pt
  \let \tempp \topskip
  \topskip 1em
	\tocspace
	\ifEnglish
	\currentpdfbookmark{TABLE OF CONTENTS}{TABLE OF CONTENTS}
  \chapter*{\textbf{\large{TABLE OF CONTENTS}}}
	\else
	\currentpdfbookmark{\.{I}\c{C}\.{I}NDEK\.{I}LER}{ICINDEKILER}
  \chapter*{\textbf{\large{\.{I}\c{C}\.{I}NDEK\.{I}LER}}}
	\fi
  \thispagestyle{myheadings}
  \@starttoc{toc}
  \doublespace  \topskip \tempp
\ifIndent
\setlength{\parindent}{2em}        % Width of paragraph indentation.
\setlength{\parskip}{0pt} 	       % No extra vertical space between paragraphs.
\else
\setlength{\parindent}{0em}        % No paragraph indentation.
\setlength{\parskip}{12pt} 	       % 12pt extra space between paragraphs.
\fi
  }

% Chapter Definitions in TOC
\def\l@chapter#1#2{\pagebreak[3]
   \vskip 0.75em plus 1pt   % space above chapter line
    {
    \leftskip 2em\relax \rightskip \@tocrmarg \parfillskip -\rightskip
     \parindent 2em\relax\@afterindenttrue
    \interlinepenalty\@M
    \leavevmode
    \@tempdima 2em\relax       % width of box holding chapter number
    \advance\leftskip \@tempdima \hbox{}\hskip -\leftskip
     \uppercase{#1}\nobreak\leaders\hbox{$\m@th \mkern \@dotsep mu.\mkern 
       \@dotsep mu$}\hfill \nobreak \hbox to\@pnumwidth{\hfil\rm #2}\par
       }
    \vskip 1em plus 1pt}  % space below chapter line

%   these control the spacing from the left margin
%   #1 is the indentation level at which an entry is produced in the toc file
%   #2 is the total indentation from the left margin
%   #3 is the width of the box containing the chapter/section number
%
% thesis mod
\def\l@section{\@dottedtocline{1}{4em}{2em}}
\def\l@subsection{\@dottedtocline{2}{6em}{3em}}
\def\l@subsubsection{\@dottedtocline{3}{9em}{4em}}
\def\l@paragraph{\@dottedtocline{4}{10em}{5em}}
\def\l@subparagraph{\@dottedtocline{5}{11em}{6em}}

%    ******************************************
%    *         LIST OF FIGURES PAGE           *
%    ******************************************

\def\listoffigures{\tocspace
	 \parskip 0pt
   \let \tempp \topskip
   \topskip 1em
	 \ifEnglish
   \chapter*{\textbf{\large{LIST OF FIGURES}}}
   \addcontentsline{toc}{chapter}{LIST OF FIGURES}
	 \else
   \chapter*{\textbf{\large{\c{S}EK\.{I}L L\.{I}STES\.{I}}}}
   \addcontentsline{toc}{chapter}{\c{S}EK\.{I}L L\.{I}STES\.{I}}
	 \fi
   \thispagestyle{myheadings}
   \toddhack \twoem
   \@starttoc{lof}\if@restonecol\twocolumn
   \toddhack \zeroem
   \fi\topskip \tempp \doublespace
\ifIndent
\setlength{\parindent}{2em}        % Width of paragraph indentation.
\setlength{\parskip}{0pt} 	       % No extra vertical space between paragraphs.
\else
\setlength{\parindent}{0em}        % No paragraph indentation.
\setlength{\parskip}{12pt} 	       % 12pt extra space between paragraphs.
\fi
   }

% Figures in LOF
\def\l@figure#1#2{\pagebreak[3]
	\vskip .5em plus 1pt  % space above figure line
	{\leftskip 0pt\relax \rightskip \@tocrmarg \parfillskip -\rightskip
	\parindent 0pt\relax\@afterindenttrue
	\interlinepenalty\@M
	\leavevmode               
	\@tempdima \fignumbox\relax       % width of box holding figure number \fignumbox default to 4em
	\advance\leftskip \@tempdima \hbox{}\hskip -\leftskip
	#1\nobreak\leaders\hbox{$\m@th \mkern \@dotsep mu.\mkern 
	\@dotsep mu$}\hfill \nobreak \hbox to\@pnumwidth{\hfil #2}\par}
	\vskip .5em plus 1pt}  % space below figure line
 
%    *****************************************
%    *         LIST OF TABLES PAGE           *
%    *****************************************

\def\listoftables{\tocspace
  \parskip 0pt
	\let \tempp \topskip
	\topskip 1em
	\ifEnglish
	\chapter*{\textbf{\large{LIST OF TABLES}}}
	\addcontentsline{toc}{chapter}{LIST OF TABLES}
	\else
	\chapter*{\textbf{\large{TABLO L\.{I}STES\.{I}}}}
	\addcontentsline{toc}{chapter}{TABLO L\.{I}STES\.{I}}
	\fi	
	\thispagestyle{myheadings}
	\toddhack \twoem
	\@starttoc{lot}\if@restonecol\twocolumn
	\toddhack \zeroem
	\fi\topskip \tempp \doublespace
\ifIndent
\setlength{\parindent}{2em}        % Width of paragraph indentation.
\setlength{\parskip}{0pt} 	       % No extra vertical space between paragraphs.
\else
\setlength{\parindent}{0em}        % No paragraph indentation.
\setlength{\parskip}{12pt} 	       % 12pt extra space between paragraphs.
\fi
	}

\let\l@table\l@figure

%    *******************************
%    *         VITA PAGE           *
%    *******************************

\def\vita{
 \clearpage      % Starts new page.
 \global\@topnum\z@        % Prevents figures from going at top of page.
 \@afterindentfalse        % Suppresses indent in first paragraph.  Change
 \vskip .2truein
 \ifEnglish
% \centerline {\textbf{\large{VITA}}}
 \chapter*{\textbf{\large{VITA}}}
 \addcontentsline{toc}{chapter}{VITA}
 \else
% \centerline {\textbf{\large{\"{O}ZGE\c{C}M\.{I}\c{S}}}}
 \chapter*{\textbf{\large{\"{O}ZGE\c{C}M\.{I}\c{S}}}}
 \addcontentsline{toc}{chapter}{\"{O}ZGE\c{C}M\.{I}\c{S}}
 \fi
 \bigskip}						 

%    ****************************************
%    *            PAGE STYLES               *
%    ****************************************
%
% The page style 'foo' is defined by defining the command \ps@foo.  This
% command should make only local definitions.  There should be no stray
% spaces in the definition, since they could lead to mysterious extra
% spaces in the output.
%
% The \ps@... command defines the macros \@oddhead, \@oddfoot,
% \@evenhead, and \@evenfoot to define the running heads and
% feet---e.g., \@oddhead is the macro to produce the contents of the
% heading box for odd-numbered pages.  It is called inside an \hbox of
% width \textwidth.
%
% To make headings determined by the sectioning commands, the page style
% defines the commands \chaptermark, \sectionmark, ... , where
% \chaptermark{TEXT} is called by \chapter to set a mark, and so on.
% The \...mark commands and the \...head macros are defined with the
% help of the following macros.  (All the \...mark commands should be
% initialized to no-ops.)
%
% MARKING CONVENTIONS:
% LaTeX extends TeX's \mark facility by producing two kinds of marks
% a 'left' and a 'right' mark, using the following commands:
%     \markboth{LEFT}{RIGHT} : Adds both marks.
%     \markright{RIGHT}      : Adds a 'right' mark.
%     \leftmark  : Used in the \@oddhead, \@oddfoot, \@evenhead or \@evenfoot
%                  macro, gets the current 'left'  mark.  Works like TeX's
%                  \botmark command.
%     \rightmark : Used in the \@oddhead, \@oddfoot, \@evenhead or \@evenfoot
%                  macro, gets the current 'right'  mark.  Works like TeX's
%                  \firstmark command.
% The marking commands work reasonably well for right marks 'numbered
% within' left marks--e.g., the left mark is changed by a \chapter command and
% the right mark is changed by a \section command.  However, it does
% produce somewhat anomalous results if two \bothmark's occur on the same page.
%

\mark{{}{}}   % Initializes TeX's marks

% Definition of 'headings' page style
%  Note the use of ##1 for parameter of \def\chaptermark inside the
%  \def\ps@headings.
%

\if@twoside         % If two-sided printing.
\def\ps@headings{\def\@oddfoot{}\def\@evenfoot{}%       No feet.
\def\@evenhead{
\vbox to 36pt{\hbox to \hsize{\rm\thepage \hfil} 
\vskip 37pt 
\hbox to \hsize{\leftmark\hfil Page}}}
\def\@oddhead{
\vbox to 36pt{\hbox to \hsize{\hfil \rm\thepage} 
\vskip 37pt 
\hbox to \hsize{\rightmark \hfil Page}}}
\def\chaptermark##1{\markboth {\uppercase{\ifnum \c@secnumdepth >\m@ne
      \@chapapp\ \thechapter. \ \fi ##1}}{}}
\def\sectionmark##1{\markright {\uppercase{\ifnum \c@secnumdepth >\z@
   \thesection. \ \fi ##1}}}}
\else               % If one-sided printing.
\def\ps@headings{\def\@oddfoot{}\def\@evenfoot{}%     No feet.
\def\@oddhead{
\vbox to 36pt{\hbox to \hsize{\hfil \rm\thepage} 
\vskip 37pt 
\hbox to \hsize{\rightmark \hfil Page}}} %
\def\chaptermark##1{\markright {\uppercase{\ifnum \c@secnumdepth >\m@ne
  \@chapapp\ \thechapter. \ \fi ##1}}}}
\fi

% Definition of 'myheadings' page style.
\def\ps@myheadings{
\def\@oddhead{\hbox{} \hfil \rm\thepage}
\def\@oddfoot{}
\def\@evenhead{\rm \thepage\hfil\null\hbox {}}
%\sl\leftmark\hbox {}}%
\def\@evenfoot{}
\def\sectionmark##1{}
\def\subsectionmark##1{}}

\def\ps@myheadingsnum{
\def\@oddhead{}
\def\@oddfoot{}
\def\@evenhead{}
%\sl\leftmark\hbox {}}%
\def\@evenfoot{}
\def\sectionmark##1{}
\def\subsectionmark##1{}}


%    ************************************************
%    *            EQUATION and EQNARRAY             *
%    ************************************************
%

% EQUATION and EQNARRAY -- put here because it must follow \chapter definition

\@addtoreset{equation}{chapter}   % Makes \chapter reset 'equation' counter.

\@addtoreset{equation}{appendix}   % Makes \appendix reset 'equation' counter.

\def\theequation{\arabic{chapter}.\arabic{equation}}

% \jot = 3pt      % Extra space added between lines of an eqnarray environment

% The macro \@eqnnum defines how equation numbers are to appear in equations.
%
% \def\@eqnnum{(\theequation)}
%


%    ****************************************
%    *           INITIALIZATION             *
%    ****************************************
%
% Default initializations

\ps@myheadings		    % default is `myheadings' page style
\pagenumbering{arabic}      % Arabic page numbers 
\onecolumn                  % Single-column.
\if@twoside\else\raggedbottom\fi % Ragged bottom unless twoside option.

%    ***************************************
%    *     SINGLESPACE AND DOUBLESPACE	   *
%    ***************************************     


%---Stretch the baseline BEFORE calculating the strut size. This improves
%   spacing below tabular environments etc., probably...
%   Comments are welcomed.

\def\@setsize#1#2#3#4{\@nomath#1%
   \let\@currsize#1\baselineskip
   #2\baselineskip\baselinestretch\baselineskip
   \parskip\baselinestretch\parskip
   \setbox\strutbox\hbox{\vrule height.7\baselineskip
      depth.3\baselineskip width\z@}%
   \normalbaselineskip\baselineskip#3#4}


%---Increase the space between last line of text and footnote rule.
%   This is a very untidy way to do it!

\skip\footins 20pt plus4pt minus4pt


\long\def\@footnotetext#1{\insert\footins{\def\baselinestretch{1}\footnotesize
    \interlinepenalty\interfootnotelinepenalty 
    \splittopskip\footnotesep
    \splitmaxdepth \dp\strutbox \floatingpenalty \@MM
    \hsize\columnwidth \@parboxrestore
   \edef\@currentlabel{\csname p@footnote\endcsname\@thefnmark}\@makefntext
    {\rule{\z@}{\footnotesep}\ignorespaces
      #1\strut}}}

% Fix up spacing before and after displayed math
% (arraystretch seems to do a fine job for inside LaTeX displayed math,
% since array and eqnarray seem to be affected as expected)
% Changing \baselinestretch and doing a font change also works if done here,
% but then you have to change @setsize to remove the call to @nomath)
%
\everydisplay{
   \abovedisplayskip \baselinestretch\abovedisplayskip
   \belowdisplayskip \abovedisplayskip
   \abovedisplayshortskip \baselinestretch\abovedisplayshortskip
   \belowdisplayshortskip  \baselinestretch\belowdisplayshortskip}

%    ***********************************************
%    *           DESCRIPTION PARAMETERS             *
%    ***********************************************
% Description environment is used in acronyms and symbols page

\def\descriptionlabel#1{\hspace\labelsep \bf #1}
\def\description{\list{}{\labelwidth\z@ \itemindent-\leftmargin \oneandhalfspace
       \let\makelabel\descriptionlabel}}

\let\enddescription\endlist

\newdimen\descriptionmargin
\descriptionmargin=3em


%    ***********************************************
%    *           LSTLISTING PARAMETERS             *
%    ***********************************************

\lstset{ %
%  language=Octave,                % the language of the code
  basicstyle=\normalsize,           % the size of the fonts that are used for the code
%  numbers=left,                   % where to put the line-numbers
  numberstyle=\normalsize,  % the style that is used for the line-numbers
  stepnumber=1,                   % the step between two line-numbers. If it's 1, each line 
                                  % will be numbered
%  numbersep=5pt,                  % how far the line-numbers are from the code
%  backgroundcolor=\color{white},      % choose the background color. You must add \usepackage{color}
%  showspaces=false,               % show spaces adding particular underscores
%  showstringspaces=false,         % underline spaces within strings
%  showtabs=false,                 % show tabs within strings adding particular underscores
%  frame=single,                   % adds a frame around the code
%  rulecolor=\color{black},        % if not set, the frame-color may be changed on line-breaks within not-black text (e.g. commens (green here))
  tabsize=2,                      % sets default tabsize to 2 spaces
%  captionpos=b,                   % sets the caption-position to bottom
  breaklines=true,                % sets automatic line breaking
%  breakatwhitespace=false,        % sets if automatic breaks should only happen at whitespace
%  title=\lstname,                   % show the filename of files included with \lstinputlisting;
%                                  % also try caption instead of title
%  keywordstyle=\color{blue},          % keyword style
%  commentstyle=\color{dkgreen},       % comment style
%  stringstyle=\color{mauve},         % string literal style
%  escapeinside={\%*}{*)},            % if you want to add a comment within your code
%  morekeywords={*,...}               % if you want to add more keywords to the set
	extendedchars=true,
%	basicstyle=\small,									% print whole listing small
	aboveskip={24pt},									% space above displayed listings
	belowskip={24pt},									% space below displayed listings
}

% Load hyperref as last package in order to make footnote links work
\ifpdf
	\usepackage[debug,pdftex,linktocpage,unicode,hidelinks,pageanchor=false]{hyperref}
	\ifEnglish
		\AtBeginDocument{\hypersetup{pdftitle=\titlepdf,pdfauthor=\student,pdfkeywords=\keywords}}
	\else
		\AtBeginDocument{\hypersetup{pdftitle=\titlepdf,pdfauthor=\student,pdfkeywords=\anahtarkelimeler}}
	\fi
	\usepackage[all]{hypcap}
\else
	\usepackage[debug,linktocpage,unicode,hidelinks,pageanchor=false]{hyperref}
	\usepackage[all]{hypcap}
\fi

